@@ -34,15 +34,20 @@ class Auth:
     def __init__(self, refresh_token: str, client_secret: str):
         self.__refresh_token = refresh_token
         self.__client_secret = client_secret
-        self.__access_token, self.__expiring_date = self.__refresh_access_token()
+        self.__access_token, self.__expiring_date = self.__create_access_token()
+
+    @staticmethod
+    def __print_valid_to(expiring_date: datetime):
+        return "valid until " + str(expiring_date.strftime("%Y-%m-%dT%H:%M:%S"))
 
     @property
     def access_token(self) -> str:
         if datetime.now() > (self.__expiring_date + timedelta(seconds=60)):
-            self.__refresh_access_token()
+            logging.info("access token expired (" + self.__print_valid_to(self.__expiring_date) + "). Requesting new access token")
+            self.__access_token, self.__expiring_date = self.__create_access_token()
         return self.__access_token
 
-    def __refresh_access_token(self) -> Tuple[str, datetime]:
+    def __create_access_token(self) -> Tuple[str, datetime]:
         data = {"grant_type": "refresh_token",
                 "refresh_token": self.__refresh_token,
                 "client_secret": self.__client_secret}
@@ -50,6 +55,7 @@ class Auth:
         response.raise_for_status()
         data = response.json()
         expiring_date = datetime.now() + timedelta(seconds=data['expires_in'])
+        logging.info("new access token created ("+ self.__print_valid_to(expiring_date) + ")")
         return data['access_token'], expiring_date
 
     def store(self, filename : str = DEFAULT_FILENAME):
